@@ -38,7 +38,8 @@ enum
 {
   PROP_LAYOUT_MODE = 1,
   PROP_SNAP_TO_GRID,
-  PROP_APPLET_PADDING
+  PROP_APPLET_PADDING,
+  PROP_DEFAULT_ALPHA
 
 };
 
@@ -375,8 +376,6 @@ hildon_home_area_layout_mode_start (HildonHomeArea *area)
   HildonHomeAreaPriv      *priv;
   priv = HILDON_HOME_AREA_GET_PRIVATE (area);
 
-  priv->layout_changed = FALSE;
-
   gtk_container_foreach (GTK_CONTAINER (area),
                          (GtkCallback)hildon_desktop_home_item_set_layout_mode,
                          (gpointer)TRUE);
@@ -387,10 +386,16 @@ hildon_home_area_layout_mode_start (HildonHomeArea *area)
 static void
 hildon_home_area_layout_mode_end (HildonHomeArea *area)
 {
+  HildonHomeAreaPriv      *priv;
+  priv = HILDON_HOME_AREA_GET_PRIVATE (area);
+  
   gtk_container_foreach (GTK_CONTAINER (area),
                         (GtkCallback)hildon_desktop_home_item_set_layout_mode,
                          (gpointer)FALSE);
   g_signal_emit_by_name (area, "layout-mode-ended");
+
+  priv->layout_changed = FALSE;
+
 }
 
 static void
@@ -434,6 +439,7 @@ hildon_home_area_add (GtkContainer *area, GtkWidget *applet)
     {
       g_debug ("Batch adding it");
       priv->to_add = g_list_append (priv->to_add, applet);
+      g_signal_emit_by_name (area, "layout-changed");
       return;
     }
 
@@ -799,15 +805,17 @@ hildon_home_area_batch_add (HildonHomeArea *area)
 /*  g_list_free (priv->to_add);*/
 
 #else
-  GdkRectangle          area_rectangle = {0};
+  GdkRectangle         *area_rectangle;
   GList                *region = NULL, *i;
 
   priv = HILDON_HOME_AREA_GET_PRIVATE (area);
 
-  area_rectangle.width  = GTK_WIDGET (area)->allocation.width;
-  area_rectangle.height = GTK_WIDGET (area)->allocation.height;
+  area_rectangle = create_rectangle (0,
+                                     0,
+                                     GTK_WIDGET (area)->allocation.width,
+                                      GTK_WIDGET (area)->allocation.height);
 
-  region = g_list_append (region, &area_rectangle);
+  region = g_list_append (region, area_rectangle);
 
   gtk_container_foreach (GTK_CONTAINER (area),
                          (GtkCallback)remove_widget,
@@ -853,11 +861,11 @@ hildon_home_area_batch_add (HildonHomeArea *area)
               gtk_container_add (GTK_CONTAINER (area), w);
               
               layout->width  = req.width;
-              if (layout->x + layout->width < area_rectangle.width)
+              if (layout->x + layout->width < area_rectangle->width)
                 layout->width += priv->applet_padding;
 
               layout->height = req.height;
-              if (layout->y + layout->height < area_rectangle.height)
+              if (layout->y + layout->height < area_rectangle->height)
                 layout->height += priv->applet_padding;
 
               if (layout->x)
@@ -889,7 +897,7 @@ hildon_home_area_batch_add (HildonHomeArea *area)
           g_list_foreach (region, (GFunc)g_free, NULL);
           g_list_free (region);
           region = NULL;
-          region = g_list_append (region, &area_rectangle);
+          region = g_list_append (region, area_rectangle);
         }
       else
         i = g_list_next (i);
